@@ -55,7 +55,7 @@ SERVE_STATIC = True
 URL_PREFIX = '/'
 WSGI_SCRIPT_FILE_NAME = 'wsgi.py'
 WSGI_PROCESS_GROUP = 'apache'
-WSGI_PROCESS_NAME = PROJECT_NAME
+#WSGI_PROCESS_NAME = PROJECT_NAME
 WSGI_PROCESS_USER = 'apache'
 WSGI_PROCESSES_COUNT = 2
 WSGI_PYTHON_OPTIMIZE_LEVEL = 1
